<?php
namespace App\Controller;

use App\Utils\TypesTransformer;
use App\Utils\XMLLoader;
use App\Utils\XMLTransformer;
use DOMDocument;
use SimpleXMLElement;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class DemoController extends AbstractController
{
    /**
     * @Route("/")
     */
    public function demo(): Response
    {
        return $this->render('demo/demo.html.twig');
    }

    /**
     * @Route("/processXML",methods={"POST"})
     */
    public function processXML(Request $request, XMLLoader $loader): Response
    {
        $xml = $request->request->get('initialData');
        $typeData = $request->request->get('typeData');

        $typesTransformer = new TypesTransformer();
        if ($typeData === 'json') {
            $array = json_decode ($xml, true);
            $xml = new SimpleXMLElement('<root/>');
            $typesTransformer->arrayToXml($array, $xml);
            $doc = new DOMDocument();
            $doc->formatOutput = TRUE;
            $doc->loadXML($xml->asXML());
            $xml = $doc->saveXML();
        } elseif ($typeData === 'csv') {
            $xml = $typesTransformer->convertCsvToXmlString($xml);
        }

        $xmlReader = new \XMLReader();
        $xmlReader->XML($xml);
        $loader->loadXML($xmlReader);
        $foundElements = $loader->getTree();
        $response = new Response();
        $response->setContent(json_encode([
            'foundElements' => $foundElements,
        ]));
        $response->headers->set('Content-Type', 'application/json');
        return $response;
    }

    /**
     * @Route("/transformXML",methods={"POST"})
     */
    public function transformXML(Request $request, XMLTransformer $transformer): Response {
        $newTemplate = $request->request->get('newTemplate');
        $initialData = $request->request->get('initialData');
        $xmlReader = new \XMLReader();
        $xmlReader->XML($initialData);
        $transformer->transformToResultData($xmlReader, $newTemplate);
        $xml = $transformer->getResultXML();
        $response = new Response();
        $response->setContent(json_encode([
            'xml' => $xml,
        ]));
        $response->headers->set('Content-Type', 'application/json');
        return $response;
    }

}